@@ -1,3 +1,3 @@
 from xyw_macro.hook import Condition, Configuration, VK
 from xyw_macro.macro import Macro
-from xyw_macro.notify import confirm_box, input_box
+from xyw_macro.notify import confirm_box, input_box, InputBox
