@@ -5,6 +5,7 @@ import win32clipboard
 import win32con
 import webbrowser
 import os
+import subprocess
 from xyw_macro.win32 import send_kb_event, send_unicode
 from xyw_macro.hook import VK
 
@@ -65,7 +66,9 @@ def get_clipboard_files():
     获取剪切板中文件的文件地址
     :return: 地址元组
     """
+    press_copy()
     if win32clipboard.IsClipboardFormatAvailable(win32con.CF_HDROP) == 0:
+        print('no')
         return
     win32clipboard.OpenClipboard()
     data = win32clipboard.GetClipboardData(win32con.CF_HDROP)
@@ -79,7 +82,11 @@ def run_cmd(cmd):
     :param cmd:
     :return:
     """
-    os.system(cmd)
+    # os.system(cmd)
+    try:
+        subprocess.run(cmd, shell=True, timeout=1)
+    except subprocess.TimeoutExpired:
+        pass
 
 
 def open_file(path):
