@@ -354,7 +354,10 @@ class Configuration:
             self.__parts = self.FUNCTION
         else:
             self.__parts = parts
-        self.__excepts = excepts
+        if excepts is None:
+            self.__excepts = []
+        else:
+            self.__excepts = excepts
 
         self.__commands = {}
 
